@@ -25,8 +25,9 @@ from sphinx.writers.texinfo import TexinfoTranslator
 TEXINFO_WARNINGS = ENV_WARNINGS + """\
 %(root)s/index.rst:\\d+: WARNING: unknown option: &option
 %(root)s/index.rst:\\d+: WARNING: citation not found: missing
-%(root)s/index.rst:\\d+: WARNING: no matching candidate for image URI u'foo.\\*'
-%(root)s/index.rst:\\d+: WARNING: no matching candidate for image URI u'svgimg.\\*'
+%(root)s/index.rst:\\d+: WARNING: a suitable image for texinfo builder not found: foo.\\*
+%(root)s/index.rst:\\d+: WARNING: a suitable image for texinfo builder not found: \
+\\['application/pdf', 'image/svg\\+xml'\\] \\(svgimg.\\*\\)
 """
 
 if PY3:
@@ -49,6 +50,10 @@ def test_texinfo_warnings(app, status, warning):
 def test_texinfo(app, status, warning):
     TexinfoTranslator.ignore_missing_images = True
     app.builder.build_all()
+    result = (app.outdir / 'SphinxTests.texi').text(encoding='utf8')
+    assert ('@anchor{markup doc}@anchor{12}'
+            '@anchor{markup id1}@anchor{13}'
+            '@anchor{markup testing-various-markup}@anchor{14}' in result)
     # now, try to run makeinfo over it
     cwd = os.getcwd()
     os.chdir(app.outdir)
@@ -67,3 +72,24 @@ def test_texinfo(app, status, warning):
                 assert False, 'makeinfo exited with return code %s' % retcode
     finally:
         os.chdir(cwd)
+
+
+@pytest.mark.sphinx('texinfo', testroot='markup-rubric')
+def test_texinfo_rubric(app, status, warning):
+    app.build()
+
+    output = (app.outdir / 'python.texi').text()
+    assert '@heading This is a rubric' in output
+    assert '@heading This is a multiline rubric' in output
+
+
+@pytest.mark.sphinx('texinfo', testroot='markup-citation')
+def test_texinfo_citation(app, status, warning):
+    app.builder.build_all()
+
+    output = (app.outdir / 'python.texi').text()
+    assert 'This is a citation ref; @ref{1,,[CITE1]} and @ref{2,,[CITE2]}.' in output
+    assert ('@anchor{index cite1}@anchor{1}@w{(CITE1)} \n'
+            'This is a citation\n') in output
+    assert ('@anchor{index cite2}@anchor{2}@w{(CITE2)} \n'
+            'This is a multiline citation\n') in output
