@@ -5,20 +5,19 @@
 
     Test the sphinx.quickstart module.
 
-    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 import sys
 import time
 
+import pytest
 from six import PY2, text_type, StringIO
 from six.moves import input
 
-from util import raises, with_tempdir, SkipTest
-
 from sphinx import application
-from sphinx import quickstart as qs
+from sphinx.cmd import quickstart as qs
 from sphinx.util.console import nocolor, coloron
 from sphinx.util.pycompat import execfile_
 
@@ -62,27 +61,7 @@ def teardown_module():
     coloron()
 
 
-def test_quickstart_inputstrip():
-    d = {}
-    answers = {
-        'Q1': 'Y',
-        'Q2': ' Yes ',
-        'Q3': 'N',
-        'Q4': 'N ',
-    }
-    qs.term_input = mock_input(answers)
-    qs.do_prompt(d, 'k1', 'Q1')
-    assert d['k1'] == 'Y'
-    qs.do_prompt(d, 'k2', 'Q2')
-    assert d['k2'] == 'Yes'
-    qs.do_prompt(d, 'k3', 'Q3')
-    assert d['k3'] == 'N'
-    qs.do_prompt(d, 'k4', 'Q4')
-    assert d['k4'] == 'N'
-
-
 def test_do_prompt():
-    d = {}
     answers = {
         'Q2': 'v2',
         'Q3': 'v3',
@@ -91,41 +70,45 @@ def test_do_prompt():
         'Q6': 'foo',
     }
     qs.term_input = mock_input(answers)
-    try:
-        qs.do_prompt(d, 'k1', 'Q1')
-    except AssertionError:
-        assert 'k1' not in d
-    else:
-        assert False, 'AssertionError not raised'
-    qs.do_prompt(d, 'k1', 'Q1', default='v1')
-    assert d['k1'] == 'v1'
-    qs.do_prompt(d, 'k3', 'Q3', default='v3_default')
-    assert d['k3'] == 'v3'
-    qs.do_prompt(d, 'k2', 'Q2')
-    assert d['k2'] == 'v2'
-    qs.do_prompt(d, 'k4', 'Q4', validator=qs.boolean)
-    assert d['k4'] is True
-    qs.do_prompt(d, 'k5', 'Q5', validator=qs.boolean)
-    assert d['k5'] is False
-    raises(AssertionError, qs.do_prompt, d, 'k6', 'Q6', validator=qs.boolean)
+
+    assert qs.do_prompt('Q1', default='v1') == 'v1'
+    assert qs.do_prompt('Q3', default='v3_default') == 'v3'
+    assert qs.do_prompt('Q2') == 'v2'
+    assert qs.do_prompt('Q4', validator=qs.boolean) is True
+    assert qs.do_prompt('Q5', validator=qs.boolean) is False
+    with pytest.raises(AssertionError):
+        qs.do_prompt('Q6', validator=qs.boolean)
+
+
+def test_do_prompt_inputstrip():
+    answers = {
+        'Q1': 'Y',
+        'Q2': ' Yes ',
+        'Q3': 'N',
+        'Q4': 'N ',
+    }
+    qs.term_input = mock_input(answers)
+
+    assert qs.do_prompt('Q1') == 'Y'
+    assert qs.do_prompt('Q2') == 'Yes'
+    assert qs.do_prompt('Q3') == 'N'
+    assert qs.do_prompt('Q4') == 'N'
 
 
 def test_do_prompt_with_nonascii():
-    d = {}
     answers = {
         'Q1': u'\u30c9\u30a4\u30c4',
     }
     qs.term_input = mock_input(answers)
     try:
-        qs.do_prompt(d, 'k1', 'Q1', default=u'\u65e5\u672c')
+        result = qs.do_prompt('Q1', default=u'\u65e5\u672c')
     except UnicodeEncodeError:
-        raise SkipTest(
+        raise pytest.skip.Exception(
             'non-ASCII console input not supported on this encoding: %s',
             qs.TERM_ENCODING)
-    assert d['k1'] == u'\u30c9\u30a4\u30c4'
+    assert result == u'\u30c9\u30a4\u30c4'
 
 
-@with_tempdir
 def test_quickstart_defaults(tempdir):
     answers = {
         'Root path': tempdir,
@@ -150,7 +133,6 @@ def test_quickstart_defaults(tempdir):
     assert ns['copyright'] == '%s, Georg Brandl' % time.strftime('%Y')
     assert ns['version'] == '0.1'
     assert ns['release'] == '0.1'
-    assert ns['todo_include_todos'] is False
     assert ns['html_static_path'] == ['_static']
     assert ns['latex_documents'] == [
         ('index', 'SphinxTest.tex', 'Sphinx Test Documentation',
@@ -163,7 +145,6 @@ def test_quickstart_defaults(tempdir):
     assert (tempdir / 'make.bat').isfile()
 
 
-@with_tempdir
 def test_quickstart_all_answers(tempdir):
     answers = {
         'Root path': tempdir,
@@ -181,10 +162,11 @@ def test_quickstart_all_answers(tempdir):
         'intersphinx': 'no',
         'todo': 'y',
         'coverage': 'no',
-        'pngmath': 'N',
+        'imgmath': 'N',
         'mathjax': 'no',
         'ifconfig': 'no',
         'viewcode': 'no',
+        'githubpages': 'no',
         'Create Makefile': 'no',
         'Create Windows command file': 'no',
         'Do you want to use the epub builder': 'yes',
@@ -215,7 +197,6 @@ def test_quickstart_all_answers(tempdir):
     assert ns['latex_documents'] == [
         ('contents', 'STASI.tex', u'STASI™ Documentation',
          u'Wolfgang Schäuble \\& G\'Beckstein', 'manual')]
-    assert ns['epub_author'] == u'Wolfgang Schäuble & G\'Beckstein'
     assert ns['man_pages'] == [
         ('contents', 'stasi', u'STASI™ Documentation',
          [u'Wolfgang Schäuble & G\'Beckstein'], 1)]
@@ -230,7 +211,6 @@ def test_quickstart_all_answers(tempdir):
     assert (tempdir / 'source' / 'contents.txt').isfile()
 
 
-@with_tempdir
 def test_generated_files_eol(tempdir):
     answers = {
         'Root path': tempdir,
@@ -244,14 +224,13 @@ def test_generated_files_eol(tempdir):
     qs.generate(d)
 
     def assert_eol(filename, eol):
-        content = filename.bytes().decode('unicode-escape')
+        content = filename.bytes().decode()
         assert all([l[-len(eol):] == eol for l in content.splitlines(True)])
 
     assert_eol(tempdir / 'make.bat', '\r\n')
     assert_eol(tempdir / 'Makefile', '\n')
 
 
-@with_tempdir
 def test_quickstart_and_build(tempdir):
     answers = {
         'Root path': tempdir,
@@ -277,7 +256,6 @@ def test_quickstart_and_build(tempdir):
     assert not warnings
 
 
-@with_tempdir
 def test_default_filename(tempdir):
     answers = {
         'Root path': tempdir,
@@ -297,3 +275,14 @@ def test_default_filename(tempdir):
     assert ns['latex_documents'][0][1] == 'sphinx.tex'
     assert ns['man_pages'][0][1] == 'sphinx'
     assert ns['texinfo_documents'][0][1] == 'sphinx'
+
+
+def test_extensions(tempdir):
+    qs.main(['-q', '-p', 'project_name', '-a', 'author',
+             '--extensions', 'foo,bar,baz', tempdir])
+
+    conffile = tempdir / 'conf.py'
+    assert conffile.isfile()
+    ns = {}
+    execfile_(conffile, ns)
+    assert ns['extensions'] == ['foo', 'bar', 'baz']
